@@ -1,5 +1,5 @@
 package DBIx::Class::Helper::ResultSet::Random;
-our $VERSION = '2.00000';
+our $VERSION = '2.00000_1';
 
 use strict;
 use warnings;
@@ -18,7 +18,7 @@ my %rand_order_by = (
    'DBIx::Class::Storage::DBI::Oracle'                     => 'dbms_random.value',
 );
 
-sub _rand_order_by {
+sub rand_order_by {
    return $rand_order_by{ref shift->result_source->storage} || 'RAND()';
 }
 
@@ -32,7 +32,7 @@ sub rand {
    $self->throw_exception('rand can only return an integer amount of rows')
       unless $amount == int $amount;
 
-   my $order_by = $self->_rand_order_by;
+   my $order_by = $self->rand_order_by;
 
    return $self->search(undef, { rows=> $amount, order_by => \$order_by});
 }
@@ -49,7 +49,7 @@ DBIx::Class::Helper::ResultSet::Random - Get random rows from a ResultSet
 
 =head1 VERSION
 
-version 2.00000
+version 2.00000_1
 
 =head1 SYNOPSIS
 
@@ -93,7 +93,7 @@ This method takes a single argument, being the size of the random ResultSet
 to return.  It defaults to 1.  This Component will throw exceptions if the
 argument is not an integer or not greater than zero.
 
-=head2 _rand_order_by
+=head2 rand_order_by
 
 This module currently does an C<ORDER BY> on some db specific function.  If for
 some reason it guesses incorrectly for your database the easiest way to fix
@@ -102,7 +102,7 @@ method.  So for example, if your db uses C<RAND()> instead of C<RANDOM()> and
 it's not in the predefined list of dbs you could just do the following in your
 ResultSet class:
 
- sub _rand_order_by { 'RAND()' }
+ sub rand_order_by { 'RAND()' }
 
 =head1 AUTHOR
 
