@@ -1,5 +1,5 @@
 package DBIx::Class::Helper::Row::JoinTable;
-our $VERSION = '2.00000';
+our $VERSION = '2.00000_1';
 
 use strict;
 use warnings;
@@ -8,7 +8,22 @@ use warnings;
 
 use DBIx::Class::Helpers::Util 'get_namespace_parts';
 use Lingua::EN::Inflect ();
-use String::CamelCase ();
+
+BEGIN {
+    our $has_camel_case;
+
+    sub _has_camel_case {
+        return $has_camel_case if defined $has_camel_case;
+
+        $has_camel_case = 0;
+        eval {
+            require String::CamelCase;
+            $has_camel_case = 1;
+        };
+
+        return $has_camel_case;
+    }
+}
 
 sub _pluralize {
    my $self = shift;
@@ -20,10 +35,12 @@ sub _pluralize {
 sub _defaults {
    my ($self, $params) = @_;
 
-   $params->{namespace}           ||= [ get_namespace_parts($self) ]->[0];
-   $params->{left_method}         ||= String::CamelCase::decamelize($params->{left_class});
-   $params->{right_method}        ||= String::CamelCase::decamelize($params->{right_class});
-   $params->{self_method}         ||= String::CamelCase::decamelize($self);
+   $params->{namespace}       ||= [ get_namespace_parts($self) ]->[0];
+   if (_has_camel_case) {
+      $params->{left_method}  ||= String::CamelCase::decamelize($params->{left_class});
+      $params->{right_method} ||= String::CamelCase::decamelize($params->{right_class});
+      $params->{self_method}  ||= String::CamelCase::decamelize($self);
+   }
    $params->{left_method_plural}  ||= $self->_pluralize($params->{left_method});
    $params->{right_method_plural} ||= $self->_pluralize($params->{right_method});
    $params->{self_method_plural}  ||= $self->_pluralize($params->{self_method});
@@ -181,7 +198,7 @@ DBIx::Class::Helper::Row::JoinTable - Easily set up join tables with DBIx::Class
 
 =head1 VERSION
 
-version 2.00000
+version 2.00000_1
 
 =head1 SYNOPSIS
 
@@ -223,13 +240,13 @@ All the methods take a configuration hashref that looks like the following:
 
  {
     left_class          => 'Foo',
-    left_method         => 'foo',     # see NOTE
-    left_method_plural  => 'foos',    # see NOTE, not required, used for
+    left_method         => 'foo',     # see L</NOTE>
+    left_method_plural  => 'foos',    # see L</NOTE>, not required, used for
                                       # many_to_many rel name in right_class
                                       # which is not generated by default
     right_class         => 'Bar',
-    right_method        => 'bar',     # see NOTE
-    right_method_plural => 'bars',    # see NOTE, not required, used for
+    right_method        => 'bar',     # see L</NOTE>
+    right_method_plural => 'bars',    # see L</NOTE>, not required, used for
                                       # many_to_many rel name in left_class
                                       # which is not generated by default
     namespace           => 'MyApp',   # default is guessed via *::Foo
@@ -276,8 +293,9 @@ This method sets the table to "${left_class}_${right_class}".
 
 =head2 NOTE
 
-This module uses L<String::CamelCase> to default the method names and uses
-L<Lingua::EN::Inflect> for pluralization.
+This module uses L<String::CamelCase> to default the method names if it is
+installed.  Currently it fails pod tests, so I'm not making it a requirement.
+Also will use L<Lingua::EN::Inflect> for pluralization.
 
 =head1 CHANGES BETWEEN RELEASES
 
